@@ -10,7 +10,7 @@ int main(int argc, char *argv[])
   int remote_port = 5051;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+  //MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
   agency = MC_Initialize(port, &options);
 
   /* Note: The third argument of the following function may also be a
