@@ -16,7 +16,7 @@ MCAgent_t makeAgent(int port, char* filename, char* agentName)
   sprintf(address, "monkey.engr.ucdavis.edu:%d", port);
 
   agent = MC_ComposeAgent(agentName, address, 
-     "monkey.engr.ucdavis.edu", code, NULL, address, NULL, 0);
+     "monkey.engr.ucdavis.edu", code, NULL, address, 0);
   return agent;
 }
 
