@@ -12,11 +12,9 @@ int main(int argc, char *argv[])
   int local_port = 5052;
  
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+  MC_SetThreadOn(&options, MC_THREAD_CP); /* Turn off command prompt */
   agency = MC_Initialize(local_port, &options);
 
-  printf("Mobile-C Started\n");
-
   MC_MainLoop(agency);
 
   MC_End(agency);
