@@ -22,10 +22,12 @@ int main(int argc, char *argv[])
   /* Init the agency */
   MCAgency_t agency;
   MCAgencyOptions_t options;
+  int port=5051;
+  int remote_port=5050;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
-  agency = MC_Initialize(5051, &options);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+  agency = MC_Initialize(port, &options);
 
   /* Note: The third argument of the following function may also be a
      valid IP address in the form of a string. i.e. 192.168.0.1 */
@@ -33,7 +35,7 @@ int main(int argc, char *argv[])
       agency,
       "comm_agent.xml",
       "localhost",
-      5050 );
+      remote_port);
 #ifndef _WIN32
   sleep(1);
 #else
@@ -45,7 +47,7 @@ int main(int argc, char *argv[])
       agency,
       "agent_1.xml",
       "localhost",
-      5050 );
+      remote_port);
 #ifndef _WIN32
   sleep(1);
 #else
@@ -57,7 +59,7 @@ int main(int argc, char *argv[])
       agency,
       "agent_2.xml",
       "localhost",
-      5050 );
+      remote_port);
 
   MC_End(agency);
   return 0;
