@@ -1,6 +1,6 @@
  /* SVN FILE INFO
- * $Revision: 446 $ : Last Committed Revision
- * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
+ * $Revision: 457 $ : Last Committed Revision
+ * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -962,6 +962,10 @@ agent_RunChScriptThread(void* ChAgent)
   /* Get an interpreter from the list of agency interpreters */
   agent->agent_interp = interpreter_queue_CreateRetrieve(mc_platform->interpreter_queue,
 		agent->mc_platform->interp_options );
+  if(agent->agent_interp == NULL) {
+    /* Could not get a new interpreter. Abort. */
+    return NULL;
+  }
 
   /* Setup the global variables */
   //printf("mc_agent_id\n");
