@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 446 $ : Last Committed Revision
- * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
+ * $Revision: 457 $ : Last Committed Revision
+ * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -271,7 +271,11 @@ AP_GENERIC_p interpreter_queue_CreateRetrieve( struct interpreter_queue_s *queue
 	MUTEX_LOCK(queue->lock);
 	if (queue->size <= 0) {
 		interp = malloc(sizeof(ChInterp_t));
-		Ch_Initialize(*interp, interp_options);
+		if( Ch_Initialize(interp, interp_options) != CH_OK) {
+      /* Could not initialize another interpreter */
+      MUTEX_UNLOCK(queue->lock);
+      return NULL;
+    }
     /* Initialize the agent intepreter variables */
     agent_ChScriptInitVar(interp);
 		ret = interp;
