@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 446 $ : Last Committed Revision
- * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
+ * $Revision: 457 $ : Last Committed Revision
+ * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -679,8 +679,8 @@ MC_ComposeAgentS(
     const char* code,
     const char* return_var_name,
     const char* server,
-		const char* workgroup_code,
-    int persistent
+    int persistent,
+		const char* workgroup_code
     );
 
 /**
@@ -731,8 +731,8 @@ MC_ComposeAgentFromFileS(
     const char* filename,
     const char* return_var_name,
     const char* server,
-		const char* workgroup_code,
-    int persistent
+    int persistent,
+		const char* workgroup_code
     );
 
 /**
