@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 446 $ : Last Committed Revision
- * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
+ * $Revision: 457 $ : Last Committed Revision
+ * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -138,7 +138,6 @@ MC_AclSend(MCAgency_t attr, fipa_acl_message_t* acl)
       num_addresses = acl->receiver->fipa_agent_identifiers[i]->addresses->num;
     }
 
-
     if (num_addresses == 0) {
       agent = MC_FindAgentByName(
           attr,
@@ -622,8 +621,9 @@ MC_ComposeAgent(
       code,
       return_var_name,
       server,
-      NULL,
-      persistent);
+      persistent,
+      NULL
+      );
 }
 
 EXPORTMC MCAgent_t
@@ -634,8 +634,8 @@ MC_ComposeAgentS(
     const char* code,
     const char* return_var_name,
     const char* server,
-		const char* workgroup_code,
-    int persistent
+    int persistent,
+		const char* workgroup_code
     )
 {
   agent_p agent;
@@ -721,8 +721,9 @@ EXPORTMC MCAgent_t MC_ComposeAgentFromFile(
       filename,
       return_var_name,
       server,
-      NULL,
-      persistent);
+      persistent,
+      NULL
+      );
 }
 
 EXPORTMC MCAgent_t MC_ComposeAgentFromFileS(
@@ -732,8 +733,8 @@ EXPORTMC MCAgent_t MC_ComposeAgentFromFileS(
     const char* filename,
     const char* return_var_name,
     const char* server,
-		const char* workgroup_code,
-    int persistent
+    int persistent,
+		const char* workgroup_code
     )
 {
   MCAgent_t agent;
@@ -757,8 +758,9 @@ EXPORTMC MCAgent_t MC_ComposeAgentFromFileS(
      code, 
      return_var_name, 
      server,
-		 workgroup_code,
-     persistent);
+     persistent,
+		 workgroup_code
+     );
 
   return agent;
 }
@@ -1187,23 +1189,23 @@ MC_GetAllAgents(MCAgency_t attr, MCAgent_t **agents, int* num_agents) /*{{{*/
   while (agent_queue_SearchIndex(attr->mc_platform->agent_queue, index) != NULL) {
     index++;
   }
+
+  if (index == 0) {
+    *agents = NULL;
+    *num_agents = 0;
+    return -1;
+  }
+
   *agents = (MCAgent_t *)malloc(sizeof(MCAgent_t*) * index);
   *num_agents = index;
   /* Assign the agents */
-  index = 0;
-  while
-    (
-     (
-      (*agents)[index] = agent_queue_SearchIndex
+  for(index = 0; index < *num_agents; index++) {
+    (*agents)[index] = agent_queue_SearchIndex
       (
        attr->mc_platform->agent_queue,
        index
-      )
-     )
-    )
-    {
-      index++;
-    }
+      );
+  }
   if(halt)
     MC_ResumeAgency(attr);
   return 0;
@@ -2586,8 +2588,8 @@ MC_ComposeAgentS_chdl(void *varg) /*{{{*/
   code = Ch_VaArg(interp, ap, const char*);
   return_var_name = Ch_VaArg(interp, ap, const char*);
   server = Ch_VaArg(interp, ap, const char*);
-  workgroup_code = Ch_VaArg(interp, ap, const char*);
   persistent = Ch_VaArg(interp, ap, int);
+  workgroup_code = Ch_VaArg(interp, ap, const char*);
 
   retval= MC_ComposeAgentS(
       name,
