@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 446 $ : Last Committed Revision
- * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
+ * $Revision: 457 $ : Last Committed Revision
+ * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
 /*
  * Copyright (c) 2006 Regents of the University of California.
  * All rights reserved.
@@ -138,7 +138,7 @@ DATA ListSearch(list_p list, const int index)
     /* look for the index */
     for(
             parsenode = (listNode_t *)list->listhead;
-            parsenode->next != NULL;
+            parsenode != NULL;
             parsenode = (listNode_t *)parsenode->next
        )
     {
@@ -149,6 +149,10 @@ DATA ListSearch(list_p list, const int index)
         i++;
     }
 
+    if (parsenode == NULL) {
+      return NULL;
+    }
+
     /* return the entry that matches index */
     return parsenode->node_data;
 }
