@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 446 $ : Last Committed Revision
- * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
+ * $Revision: 457 $ : Last Committed Revision
+ * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -696,7 +696,7 @@ message_send_Thread( LPVOID arg )
 #endif
 		(num_tries < max_num_tries)
 		) {
-		printf("%s ERROR Socket Connect failed... errno:%s\n", message->sending_agent_name, strerror(errno));
+		printf("ERROR Socket Connect failed... errno:%s\n", strerror(errno));
 #ifndef _WIN32
 		usleep(100000);
 #else
