@@ -1,6 +1,7 @@
 using System;
 using System.Collections.Generic;
 using System.Text;
+using System.Runtime.InteropServices;
 
 /**
  * \page mcagent MCAgent
@@ -143,7 +144,7 @@ namespace LibMC
             get
             {
                 if (agent_p == IntPtr.Zero)
-                    throw new SystemException("Private agent pointer is zero!");
+                    throw new InvalidAgentException();
                 else
                     return agent_p;
             }
@@ -155,7 +156,7 @@ namespace LibMC
                     GetAgentFields();
                 }
                 else
-                    throw new SystemException("Attempting to assign new agent to non-zero agent pointer!");
+                    throw new InvalidAgentException("Attempting to assign new agent to non-zero agent pointer!");
             }
         }
 
@@ -271,6 +272,27 @@ namespace LibMC
             }*/
         }
 
+        /**
+         * \brief       Checks whether the agent is valid.
+         * 
+         * Checks the internal agent pointer to see if it is
+         * non-zero.
+         * 
+         * \returns     True if the pointer is valid, false
+         *              otherwise
+         */
+        public bool Valid
+        {
+            get
+            {
+                return (agent_p != IntPtr.Zero);
+            }
+            /*set
+            {
+                type = value;
+            }*/
+        }
+
         /*
          * Static casting operators
          */
@@ -429,13 +451,73 @@ namespace LibMC
          *              function call.
          * 
          * \note        BE VERY CAREFUL! You must marshal your arguments!
-         * \todo        Find a better way to handle retval and varg
+         *              If possible, use the other CallAgentFunc that handles
+         *              marshaling automatically.
+         * \sa          Overloaded CallAgentFunc, LibMCConsole example
          */
         public int CallAgentFunc(String funcName, IntPtr retval, IntPtr varg)
         {
             return MCAgency._MC_CallAgentFunc(Agent, funcName, retval, varg);
         }
 
+        /**
+         * \brief       Calls a function in an agent script.
+         * 
+         * Calls a function in an agent's script file. This function
+         * requires boxing of parameters, but no marshaling.
+         * 
+         * \param       funcName The name of the function to call
+         * \param       retval A boxed object to hold the return value
+         * \param       varg The boxed argument to the agent function
+         * \returns     The return value of the underlying MC_CallAgentFunc
+         *              function call.
+         * 
+         * \note        This function handles marshaling of the argument
+         *              and return value. The memory provided to the agent
+         *              function for both retval and varg is not preserved
+         *              after this function call! If the memory is to be kept
+         *              by the agent, use the manually marshaled version
+         *              of this function. Also note that even though structures
+         *              can be marshaled automatically, in this function, the
+         *              type of the structure is unknown and therefore it must
+         *              be handled manually, even though the marshaling is
+         *              transparent to the user.
+         * 
+         * \sa          Overloaded CallAgentFunc, LibMCConsole example
+         */
+        public int CallAgentFunc(String funcName, ref object retval, ref object varg)
+        {
+            int temp = -1;
+            IntPtr vargp = IntPtr.Zero, retvalp = IntPtr.Zero;
+            try
+            {
+                vargp = Marshal.AllocHGlobal(Marshal.SizeOf(varg));
+                Marshal.StructureToPtr(varg, vargp, false);
+                retvalp = Marshal.AllocHGlobal(Marshal.SizeOf(retval));
+
+                temp = CallAgentFunc(funcName, // The function to call
+                    retvalp, // A place for the return value (void*)
+                    vargp);  // The marshaled pointer to the argument (a structure)
+                retval = Marshal.PtrToStructure(retvalp, retval.GetType());
+                varg = Marshal.PtrToStructure(vargp, varg.GetType());
+            }
+            catch (OutOfMemoryException ex)
+            {
+                Console.WriteLine("Error allocating memory for calling agent functions: " + ex.Message);
+            }
+            catch (ArgumentException ex)
+            {
+                Console.WriteLine("Error marshaling arguments for calling agent functions: " + ex.Message);
+            }
+            finally
+            {
+                Marshal.FreeHGlobal(vargp);
+                Marshal.FreeHGlobal(retvalp);
+            }
+
+            return temp;
+        }
+
         /**
          * \brief       Gets an agent's Ch interpreter.
          * 
@@ -475,4 +557,39 @@ namespace LibMC
             throw new Exception("GetAgentReturnData is not yet implemented!");
         }
     }
+
+    /**
+     * \brief   Exception class for use with null agent pointers
+     * 
+     * This class provides a way to inform the program that an
+     * agent was created or accessed that had an invalid
+     * internal pointer.
+     */
+    public class InvalidAgentException : SystemException
+    {
+        private const String msg = "Private agent pointer not valid.";
+
+        /**
+         * \brief   Null agent pointer exception constructor.
+         * 
+         * Constructor for the exception class. This exception
+         * simply defines a recognizable exception class and sets
+         * the exception message appropriately.
+         */
+        public InvalidAgentException()
+            : base(msg)
+        {
+        }
+
+        /**
+         * \brief   Null agent pointer exception constructor.
+         * 
+         * Constructor for the exception class. Allows the use
+         * of a custom error message.
+         */
+        public InvalidAgentException(String exc)
+            : base(exc)
+        {
+        }
+    }
 }
